@@ -25,7 +25,7 @@ use POSIX qw(tzset);
 
 our($VERSION, $canonical_time, $clamp_time);
 
-$VERSION = '0.044'; # 0.044
+$VERSION = '1.0.0'; # <https://semver.org/>
 
 sub init() {
 	$ENV{'TZ'} = 'UTC';
@@ -47,10 +47,6 @@ sub get_normalizer_for_file($) {
 
 	return undef if -d $_; # Skip directories
 
-	# ar
-	if (m/\.a$/ && _get_file_type($_) =~ m/ar archive/) {
-		return _handler('ar');
-	}
 	# cpio
 	if (m/\.cpio$/ && _get_file_type($_) =~ m/cpio archive/) {
 		return _handler('cpio');
@@ -93,15 +89,6 @@ sub get_normalizer_for_file($) {
 	if (m/\.png$/ && _get_file_type($_) =~ m/PNG image data/) {
 		return _handler('png');
 	}
-	# pom.properties, version.properties
-	if (m/\.properties$/) {
-	# Loading the handler forces the load of the javaproperties package as well
-		my $handler = _handler('javaproperties');
-		return $handler
-		  if
-		  File::StripNondeterminism::handlers::javaproperties::is_java_properties_file(
-			$_);
-	}
 	# zip
 	if (m/\.(zip|pk3|epub|whl|xpi|htb|zhfst|par)$/
 		&& _get_file_type($_) =~ m/Zip archive data|EPUB document/) {
@@ -112,7 +99,6 @@ sub get_normalizer_for_file($) {
 
 our %HANDLER_CACHE;
 our %KNOWN_HANDLERS = (
-	ar	=> 1,
 	bflt	=> 1,
 	cpio	=> 1,
 	gettext	=> 1,
